Package: rdacca.hp
Type: Package
Title: Hierarchical and Variation Partitioning for Canonical Analysis
Version: 1.1-3
Date: 2026-4-20
Depends: R (>= 3.4.0),vegan,ggplot2
Imports: utils
Authors@R: c(person("Jiangshan", "Lai", , "lai@njfu.edu.cn", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-0279-8816")),person("Kim", "Nimon", role="aut"),person("Yao", "Liu", role="aut"),person("Pedro", "Peres-Neto", role="aut"))
Maintainer: Jiangshan Lai <lai@njfu.edu.cn>
Description: This function conducts variation partitioning and hierarchical partitioning to calculate the unique, shared (referred as to "common") and individual contributions of each predictor (or matrix) towards explained variation (R-square and adjusted R-square) on canonical analysis (RDA,CCA and db-RDA), applying the algorithm of Lai J.,Zou Y., Zhang J.,Peres-Neto P.(2022) Generalizing hierarchical and variation partitioning in multiple regression and canonical analyses using the rdacca.hp R package.Methods in Ecology and Evolution,13: 782-788 <DOI:10.1111/2041-210X.13800>. 
License: GPL
URL: https://github.com/laijiangshan/rdacca.hp
Encoding: UTF-8
RoxygenNote: 7.3.1
NeedsCompilation: no
Packaged: 2026-04-21 05:39:54 UTC; lai
Author: Jiangshan Lai [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-0279-8816>),
  Kim Nimon [aut],
  Yao Liu [aut],
  Pedro Peres-Neto [aut]
Repository: CRAN
Date/Publication: 2026-04-21 08:30:14 UTC
Built: R 4.5.2; ; 2026-04-21 19:14:11 UTC; unix
