## Export regular function names (no dots)
export(rdacca.hp)
export(permu.hp)
S3method(plot, rdaccahp)
import(stats)
import(vegan)
import(ggplot2)
exportPattern("^[[:alpha:]]+")
importFrom(ggplot2,aes)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme_void)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,theme_minimal)
importFrom(ggplot2,labs)

